package ru.ispras.kmb.vending;

public class VendingMachineImpl implements VendingMachine
{
    protected int[] quantities;
    protected int[] prices;
    protected int proceeds;
    protected int credit;
    
    public VendingMachineImpl( int[] goods, int[] prices )
    {
        if( goods.length != prices.length ) throw new IllegalArgumentException( "goods.length != prices.length" );
        for( int quantity: goods )
        {
            if( quantity < 0 )
            {
                throw new IllegalArgumentException( "quantity < 0" );
            }
        }
        this.quantities = goods.clone();
        for( int price: prices)
        {
            if( price <= 0 )
            {
                throw new IllegalArgumentException( "price <= 0" );
            }
        }
        this.prices = prices.clone();
    }
    
    @Override
    public void addCredit( int amount )
    {
        credit += amount;
    }
    
    @Override
    public int getCredit()
    {
        return credit;
    }
    
    @Override
    public boolean sell( int index )
    {
        if( index < 0 || index >= quantities.length ) return false;
        if( credit < prices[index] ) return false;
        if( quantities[index] <= 0 ) return false;
        quantities[index]--;
        credit -= prices[index];
        proceeds += prices[index];
        return true;
    }
    
    @Override
    public void returnCredit()
    {
        credit = 0;
    }
    
    @Override
    public int getProceeds()
    {
        return proceeds;
    }
}
